@@ -43,7 +43,7 @@ class LanguagesPopup(Gtk.Window):
 
         self.show()
         self.map()
-        
+
         self.grab_add()
 
         self.keyboard = None
@@ -287,6 +287,7 @@ class Manager:
             'on_accelerator_key_press'        : self.on_accelerator_key_press,
             'on_accelerator_focus_in'         : self.on_accelerator_focus_in,
             'on_accelerator_focus_out'        : self.on_accelerator_focus_out,
+            'on_accelerator_backspace'        : self.on_accelerator_backspace,
             'on_languages_button_clicked'     : self.on_languages_button_clicked
         }
 
@@ -559,11 +560,10 @@ class Manager:
             self['languages_label'].set_text(', '.join(langs))
     
     def fill_fields(self):
-        node = self.current_node
-        self['accelerator'].set_text(default(node.shortcut, ''))
+        self.update_accelerator_label()
 
         buf = self['commands'].get_buffer()
-        script = default(''.join(node.get_script()), '')
+        script = default(''.join(self.current_node.get_script()), '')
 
         buf.begin_not_undoable_action()
         buf.set_text(script)
@@ -584,13 +584,20 @@ class Manager:
         for nm in ('input', 'output', 'applicability', 'save-files'):
             model = self[nm].get_model()
             piter = model.get_iter_first()
-            
             self.set_active_by_name(nm,
-                                    default(node.__getattribute__(nm.replace('-', '_')),
+                                    default(self.current_node.__getattribute__(nm.replace('-', '_')),
                                     model.get_value(piter, self.NAME_COLUMN)))
 
         self.fill_languages_button()
 
+    def update_accelerator_label(self):
+        if self.current_node.shortcut:
+            key, mods = Gtk.accelerator_parse(self.current_node.shortcut)
+            label = Gtk.accelerator_get_label(key, mods)
+            self['accelerator'].set_text(label)
+        else:
+            self['accelerator'].set_text('')
+
     def update_remove_revert(self):
         piter, node = self.get_selected_tool()
 
@@ -774,12 +781,12 @@ class Manager:
             return True
             
         col = self.accelerator_collision(name, self.current_node)
-        
+
         if col:
             dialog = Gtk.MessageDialog(self.dialog,
-                                       Gtk.DIALOG_MODAL,
-                                       Gtk.MESSAGE_ERROR,
-                                       Gtk.BUTTONS_OK,
+                                       Gtk.DialogFlags.MODAL,
+                                       Gtk.MessageType.ERROR,
+                                       Gtk.ButtonsType.CLOSE,
                                        _('This accelerator is already bound to %s') % (', '.join(map(lambda x: x.name, col)),))
 
             dialog.run()
@@ -798,20 +805,13 @@ class Manager:
         mask = event.state & Gtk.accelerator_get_default_mod_mask()
 
         if event.keyval == Gdk.KEY_Escape:
-            entry.set_text(default(self.current_node.shortcut, ''))
-            self['commands'].grab_focus()
-            return True
-        elif event.keyval == Gdk.KEY_Delete \
-          or event.keyval == Gdk.KEY_BackSpace:
-            entry.set_text('')
-            self.remove_accelerator(self.current_node)
-            self.current_node.shortcut = None
+            self.update_accelerator_label()
             self['commands'].grab_focus()
             return True
         elif event.keyval in range(Gdk.KEY_F1, Gdk.KEY_F12 + 1):
             # New accelerator
             if self.set_accelerator(event.keyval, mask):
-                entry.set_text(default(self.current_node.shortcut, ''))
+                self.update_accelerator_label()
                 self['commands'].grab_focus()
     
             # Capture all `normal characters`
@@ -820,7 +820,7 @@ class Manager:
             if mask:
                 # New accelerator
                 if self.set_accelerator(event.keyval, mask):
-                    entry.set_text(default(self.current_node.shortcut, ''))
+                    self.update_accelerator_label()
                     self['commands'].grab_focus()
             # Capture all `normal characters`
             return True
@@ -837,16 +837,22 @@ class Manager:
 
     def on_accelerator_focus_out(self, entry, event):
         if self.current_node is not None:
-            entry.set_text(default(self.current_node.shortcut, ''))
+            self.update_accelerator_label()
             self.tool_changed(self.current_node)
 
+    def on_accelerator_backspace(self, entry):
+        entry.set_text('')
+        self.remove_accelerator(self.current_node)
+        self.current_node.shortcut = None
+        self['commands'].grab_focus()
+
     def on_tool_manager_dialog_response(self, dialog, response):
         if response == Gtk.ResponseType.HELP:
-            Gedit.app_get_default().show_help(self.dialog, 'gedit', 'gedit-external-tools-plugin')
+            Gedit.App.get_default().show_help(self.dialog, 'gedit', 'gedit-plugins-external-tools')
             return
 
         self.on_tool_manager_dialog_focus_out(dialog, None)
-        
+
         self.dialog.destroy()
         self.dialog = None
         self.tools = None
@@ -854,12 +860,9 @@ class Manager:
     def on_tool_manager_dialog_focus_out(self, dialog, event):
         self.save_current_tool()
 
-        #FIXME: this is wrong, we must emit a signal and let the plugin update the menu
-        """
-        for window in gedit.app_get_default().get_windows():
-            helper = window.get_data("ExternalToolsPluginWindowData")
-            helper.menu.update()
-        """
+        for window in Gedit.App.get_default().get_windows():
+            windowactivatable = window.get_data("ExternalToolsPluginWindowData")
+            windowactivatable.menu.update()
 
     def get_cell_data_cb(self, column, cell, model, piter, user_data=None):
         tool = model.get_value(piter, self.TOOL_COLUMN)
